==> haskell-pipes-4.3.9-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.9
id: pipes-4.3.9-JxGpESv772KFJpDUB7Ucpi
key: pipes-4.3.9-JxGpESv772KFJpDUB7Ucpi
license: BSD-3-Clause
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
abi: 55005b4154edc7f727ebcd86e0d144e4
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
import-dirs: /usr/lib/ghc-8.6.5/site-local/pipes-4.3.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/pipes-4.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pipes-4.3.9
hs-libraries: HSpipes-4.3.9-JxGpESv772KFJpDUB7Ucpi
depends:
    base-4.12.0.0 exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    mmorph-1.1.2-5h7GKVLK9ep1Ipfuek8hyY mtl-2.2.2 transformers-0.5.6.2
    void-0.7.2-1ijpCmwDTXMGDRdU43YY14
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.3.9-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.9
id: pipes-4.3.9-DuzvXTetptCFTpko0lEKxS
key: pipes-4.3.9-DuzvXTetptCFTpko0lEKxS
license: BSD-3-Clause
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
abi: 5f7e4e0347b62e43180fa4824d27e32b
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
import-dirs: /usr/lib/ghc-8.6.5/site-local/pipes-4.3.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/pipes-4.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pipes-4.3.9
hs-libraries: HSpipes-4.3.9-DuzvXTetptCFTpko0lEKxS
depends:
    base-4.12.0.0 exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    mmorph-1.1.3-C3oMJRpRwaQ5uSWuFLRhoG mtl-2.2.2 transformers-0.5.6.2
    void-0.7.2-1ijpCmwDTXMGDRdU43YY14
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
